@@ -8,9 +8,9 @@ import json
 import pandas as pd
 
 from doc_utils import DocUtils
-
+from os import PathLike
+from pathlib import Path
 from typing import Dict, List, Union, Callable
-
 from relevanceai.analytics_funcs import track
 from relevanceai.dataset_api.dataset_read import Read
 
@@ -79,7 +79,7 @@ class Write(Read):
             df.insert_documents(documents)
 
         """
-        return self._insert_documents(
+        results = self._insert_documents(
             dataset_id=self.dataset_id,
             documents=documents,
             bulk_fn=bulk_fn,
@@ -90,6 +90,7 @@ class Write(Read):
             use_json_encoder=use_json_encoder,
             **kwargs,
         )
+        return self._process_insert_results(results)
 
     @track
     def insert_csv(
@@ -139,7 +140,7 @@ class Write(Read):
             df.insert_csv(csv_filename)
 
         """
-        return self._insert_csv(
+        results = self._insert_csv(
             dataset_id=self.dataset_id,
             filepath_or_buffer=filepath_or_buffer,
             chunksize=chunksize,
@@ -151,6 +152,8 @@ class Write(Read):
             col_for_id=col_for_id,
             auto_generate_id=auto_generate_id,
         )
+        self._process_insert_results(results)
+        return results
 
     @track
     def insert_pandas_dataframe(
@@ -194,6 +197,95 @@ class Write(Read):
         self.print_search_dashboard_url(self.dataset_id)
         return results
 
+    def insert_images_folder(
+        self,
+        path: Union[Path, str],
+        field: str = "images",
+        recurse: bool = True,
+        *args,
+        **kwargs,
+    ):
+        """
+        Given a path to a directory, this method loads all image-related files
+        into a Dataset.
+
+        Parameters
+        ----------
+        field: str
+            A text field of a dataset.
+
+        path: Union[Path, str]
+            The path to the directory containing images.
+
+        recurse: bool
+            Indicator that determines whether to recursively insert images from
+            subdirectories in the directory.
+
+        Returns
+        -------
+            dict
+
+        Example
+        -------
+        .. code-block::
+            from relevanceai import Client
+            client = Client()
+            ds = client.Dataset("dataset_id")
+
+            from pathlib import Path
+            path = Path("images/")
+            # list(path.iterdir()) returns
+            # [
+            #    PosixPath('image.jpg'),
+            #    PosixPath('more-images'), # a directory
+            # ]
+
+            get_all_images: bool = True
+            if get_all_images:
+                # Inserts all images, even those in the more-images directory
+                ds.insert_images_folder(
+                    field="images", path=path, recurse=True
+                )
+            else:
+                # Only inserts image.jpg
+                ds.insert_images_folder(
+                    field="images", path=path, recurse=False
+                )
+
+        """
+        if isinstance(path, str):
+            path = Path(path)
+
+            if not path.is_dir():
+                raise Exception(f"{path} is not a proper path")
+
+        from mimetypes import types_map
+
+        image_extensions = set(
+            k.lower() for k, v in types_map.items() if v.startswith("image/")
+        )
+
+        def get_paths(path: Path, images: List[str]) -> List[str]:
+            for file in path.iterdir():
+                if file.is_dir() and recurse:
+                    images.extend(get_paths(file, []))
+                elif file.is_file() and file.suffix.lower() in image_extensions:
+                    images.append(str(file))
+                else:
+                    continue
+
+            return images
+
+        images = get_paths(path, [])
+        documents = list(
+            map(
+                lambda image: {"_id": uuid.uuid4(), "path": image, field: image}, images
+            )
+        )
+        results = self.insert_documents(documents, *args, **kwargs)
+        self.image_fields.append(field)
+        return results
+
     @track
     def upsert_documents(
         self,
